using System;
using System.Collections.Generic;
using System.Text;
using System.Security;
using System.ComponentModel;

namespace InfiniTec.Security
{
    /// <summary>
    /// This callback is called whenever the username and password for an impersonation is needed.
    /// </summary>
    /// <param name="e">A <see cref="AcquireCredentialCallbackArgs" /> containing the parameters
    /// for the request.</param>
    /// <param name="source">The <see cref="SecurityContext"/> responsible for this request.</param>
    /// <returns>True, if the call was successful, false otherwise</returns>
    public delegate void AcquireCredentialCallback(object source, AcquireCredentialCallbackArgs e);

    /// <summary>
    /// Contains information about the <see cref="AcquireCredentialCallback"/>.
    /// </summary>
    public class AcquireCredentialCallbackArgs: CancelEventArgs
    {
        string _Username;
        SecureString _Password;
        string _TargetName;
        int _AttemptCount;

        /// <summary>
        /// Gets or sets the username used for the request. If <see cref="CancelEventArgs.Cancel"/> is
        /// set to false, this property must be set to the username used for the <see cref="SecurityContext"/>.
        /// </summary>
        public string Username { get { return _Username; } set { _Username = value; } }
        /// <summary>
        /// Gets or sets the password used for the request. If <see cref="CancelEventArgs.Cancel"/> is
        /// set to false, this property must be set to the password used for the <see cref="SecurityContext"/>.
        /// </summary>
        public SecureString Password { get { return _Password; } set { _Password = value; } }
        /// <summary>
        /// Gets the target name for the current request.
        /// </summary>
        public string TargetName { get { return _TargetName; } }
        /// <summary>
        /// Returns the retry count for the current request.
        /// </summary>
        public int AttemptCount { get { return _AttemptCount; } }

        /// <summary>
        /// Creates a new instance of this class.
        /// </summary>
        /// <param name="targetName">The target name for the request.</param>
        /// <param name="attemptCount">The retry count of the request.</param>
        internal AcquireCredentialCallbackArgs(string targetName, int attemptCount): base(false)
        {
            _TargetName = targetName;
            _AttemptCount = attemptCount;
            _Password = new SecureString();
        }
    }
}
